.. helperfns documentation master file, created by
   sphinx-quickstart on Mon Apr  8 11:01:52 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ``helperfns's`` documentation!
=========================================

🎀 This is a python package that contains some helper functions for machine leaning.

.. image:: images/logo.png
   :align: center
   :width: 200

.. raw:: html

   <p align="center">
      <a href="https://pypi.python.org/pypi/helperfns"><img src="https://badge.fury.io/py/helperfns.svg"></a>
      <a href="https://github.com/crispengari/helperfns/actions/workflows/CI.yml"><img src="https://github.com/crispengari/helperfns/actions/workflows/CI.yml/badge.svg"></a>
      <a href="/LICENSE"><img src="https://img.shields.io/badge/license-MIT-green"></a>
      <a href="https://pypi.python.org/pypi/helperfns"><img src="https://img.shields.io/pypi/pyversions/helperfns.svg"></a>
   </p>


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Getting Started

   installation
   usage

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Helper Functions

   functions/tables
   functions/utils
   functions/text
   functions/visualization

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: GitHub and Contribution

   github/contribution
   github/license






